@@ -7,6 +7,7 @@
 #' @param asym logical; \code{FALSE} (default) Allows for asymmetrical dependencies.
 #' @param p.value logical; \code{FALSE} (default) Generates 100 independent random permutations to test results against and plots 95 percent confidence intervals along with all results.
 #' @param print.map logical; \code{FALSE} (default) Plots quadrant means, or p-value replicates.
+#' @param ncores integer; value specifying the number of cores to be used in the parallelized  procedure. If NULL (default), the number of cores to be used is equal to the number of cores of the machine - 1.
 #' @return Returns the bi-variate \code{"Correlation"} and \code{"Dependence"} or correlation / dependence matrix for matrix input.
 #'
 #' @note
@@ -32,9 +33,13 @@ NNS.dep = function(x,
                    y = NULL,
                    asym = FALSE,
                    p.value = FALSE,
-                   print.map = FALSE){
+                   print.map = FALSE,
+                   ncores = NULL){
 
-  if(any(class(x)%in%c("tbl","data.table"))) x <- as.vector(unlist(x))
+
+
+  if(any(class(x)%in%c("tbl","data.table")) && !is.null(y)) x <- as.vector(unlist(x))
+  if(any(class(y)%in%c("tbl","data.table"))) y <- as.vector(unlist(y))
 
   if(sum(is.na(x)) > 0) stop("You have some missing values, please address.")
 
@@ -52,7 +57,7 @@ NNS.dep = function(x,
     obs <- max(10, l/5)
 
     # Define segments
-    if(print.map) PART <- NNS.part(x, y, order = NULL, obs.req = obs, min.obs.stop = TRUE, type = "XONLY", Voronoi = TRUE) else PART <- NNS.part(x, y, order = NULL, obs.req = obs, min.obs.stop = TRUE, type = "XONLY", Voronoi = FALSE)
+    if(print.map) PART <- suppressWarnings(NNS.part(x, y, order = NULL, obs.req = obs, min.obs.stop = TRUE, type = "XONLY", Voronoi = TRUE)) else PART <- suppressWarnings(NNS.part(x, y, order = NULL, obs.req = obs, min.obs.stop = TRUE, type = "XONLY", Voronoi = FALSE))
 
     if(dim(PART$regression.points)[1]==0) return(list("Correlation" = 0, "Dependence" = 0))
 
@@ -62,21 +67,27 @@ NNS.dep = function(x,
     PART[, weights := .N/l, by = prior.quadrant]
     weights <- PART[, weights[1], by = prior.quadrant]$V1
 
+    error_fn = function(x, y){
+      max(0, min(1, (Co.UPM(1, 1, x, y, target.x = mean(x), target.y = mean(y)) +
+                                 Co.UPM(1, 1, x, y, target.x = mean(x), target.y = mean(y))) /
+                             (D.UPM(1, 1, x, y, target.x = mean(x), target.y = mean(y)) +
+                                D.LPM(1, 1, x, y, target.x = mean(x), target.y = mean(y)))))
+    }
+
     ll <- expression(max(min(100, .N), 8))
     res <- suppressWarnings(tryCatch(PART[,  sign(cor(x[1:eval(ll)],y[1:eval(ll)]))*summary(lm(y[1:eval(ll)]~poly(x[1:eval(ll)], max(1, min(10, as.integer(sqrt(.N))-1)), raw = TRUE)))$r.squared, by = prior.quadrant],
-                                     error = function(e) PART[, NNS.copula(cbind(x,y), ncores = 1), by = prior.quadrant]))
+                                     error = function(e) error_fn(x, y)))
 
-    if(sum(is.na(res))>0) res[is.na(res)] <- NNS.copula(cbind(x,y), ncores = 1)
+    if(sum(is.na(res))>0) res[is.na(res)] <- error_fn(x, y)
 
     # Compare each asymmetry
     res_xy <- suppressWarnings(tryCatch(PART[,  sign(cor(x[1:eval(ll)],(y[1:eval(ll)])))*summary(lm(abs(y[1:eval(ll)])~poly(x[1:eval(ll)], max(1, min(10, as.integer(sqrt(.N))-1)), raw = TRUE)))$r.squared, by = prior.quadrant],
-                                        error = function(e) PART[, NNS.copula(cbind(x,y), ncores = 1), by = prior.quadrant]))
+                                        error = function(e) error_fn(x, y)))
     res_yx <- suppressWarnings(tryCatch(PART[,  sign(cor(y[1:eval(ll)],(x[1:eval(ll)])))*summary(lm(abs(x[1:eval(ll)])~poly(y[1:eval(ll)], max(1, min(10, as.integer(sqrt(.N))-1)), raw = TRUE)))$r.squared, by = prior.quadrant],
-                                        error = function(e) PART[, NNS.copula(cbind(x,y), ncores = 1), by = prior.quadrant]))
-
-    if(sum(is.na(res_xy))>0) res_xy[is.na(res_xy)] <- NNS.copula(cbind(x,y), ncores = 1)
-    if(sum(is.na(res_yx))>0) res_yx[is.na(res_yx)] <- NNS.copula(cbind(x,y), ncores = 1)
+                                        error = function(e) error_fn(x, y)))
 
+    if(sum(is.na(res_xy))>0) res_xy[is.na(res_xy)] <- error_fn(x, y)
+    if(sum(is.na(res_yx))>0) res_yx[is.na(res_yx)] <- error_fn(x, y)
 
     if(asym) dependence <- sum(abs(res_xy$V1) * weights) else dependence <- max(sum(abs(res$V1) * weights),
                                                                                 sum(abs(res_xy$V1) * weights),
@@ -110,7 +121,7 @@ NNS.dep = function(x,
     if(p.value){
       original.par <- par(no.readonly = TRUE)
 
-      nns.mc <- apply(x, 2, function(g) NNS.dep(x[,1], g))
+      nns.mc <- apply(x, 2, function(g) NNS.dep(x[,1], g, ncores = ncores))
 
       ## Store results
       cors <- unlist(lapply(nns.mc, "[[", 1))
@@ -144,7 +155,7 @@ NNS.dep = function(x,
                   "Dependence p.value" = min(LPM(0, deps[2], deps[-c(1,2)]),
                                              UPM(0, deps[2], deps[-c(1,2)])),
                   "Dependence 95% CIs" = c(dep_lower_CI, dep_upper_CI)))
-    } else return(NNS.dep.matrix(x, asym = asym))
+    } else return(NNS.dep.matrix(x, asym = asym, ncores = ncores))
   }
 
 }
