@@ -7,7 +7,6 @@ library(data.table)
 require(knitr)
 require(rgl)
 require(meboot)
-require(plyr)
 require(tdigest)
 require(dtw)
 
@@ -21,9 +20,9 @@ test.set = sample(150,10)
 a = NNS.boost(IVs.train = iris[-test.set, 1:4], 
               DV.train = iris[-test.set, 5],
               IVs.test = iris[test.set, 1:4],
-              epochs = 100, learner.trials = 100, 
+              epochs = 10, learner.trials = 10, 
               status = FALSE, balance = TRUE,
-              type = "CLASS")
+              type = "CLASS", folds = 1)
 
 a$results
 
@@ -36,7 +35,7 @@ b = NNS.stack(IVs.train = iris[-test.set, 1:4],
               DV.train = iris[-test.set, 5],
               IVs.test = iris[test.set, 1:4],
               type = "CLASS", balance = TRUE,
-              ncores = 1)
+              ncores = 1, folds = 1)
 
 b
 
