@@ -65,9 +65,9 @@ x <- rnorm(100); y <- rnorm(100)
 
 nns.params <- NNS.stack(IVs.train = cbind(x, x),
                         DV.train = y,
-                        method = 1)
+                        method = 1, ncores = 1)
 
 NNS.reg(cbind(x, x), y, 
         n.best = nns.params$NNS.reg.n.best,
-        point.est = cbind(x, x))
+        point.est = cbind(x, x), ncores = 1)
 
